@@ -15,7 +15,7 @@ def read_csv(filename, variable_names=[], validate=True):
         variable_names   list of variables to read (default: read all)
 
     Returns:
-        traj             the trajectoies read from the CSV file
+        traj             the trajectories read from the CSV file
     """
 
     # pass an empty string as deletechars to preserve special characters
@@ -143,8 +143,25 @@ def validate_signal(t, y, t_ref, y_ref, num=1000, dx=20, dy=0.1):
     return t_band, y_min, y_max, i_out
 
 
+def validate_fmu(filename):
+    """ Validate an FMU
+
+    Returns:
+        a list of the problems found
+    """
+
+    from . import read_model_description
+
+    try:
+        read_model_description(filename, validate=True)
+    except Exception as e:
+        return [str(e)]
+
+    return []
+
+
 def validate_result(result, reference, stop_time=None):
-    """ Validate a simulation result agains a reference result
+    """ Validate a simulation result against a reference result
 
     Parameters:
         result      structured NumPy array where the first column is the time
@@ -493,7 +510,7 @@ def compile_dll(model_description, sources_dir, compiler=None):
     """ Compile the shared library
 
     Parameters:
-        sources_dir:    directory that conatains the FMU's source code
+        sources_dir:    directory that contains the FMU's source code
         compiler:       compiler to use (None: use Visual C on Windows, GCC otherwise)
     """
 
